import ujson


class Sensors:
    def __init__(self):
        self.filename = '/usr/sensors.json'
        self.sensors = {}

        self.Load()

    def New(self, name, lower_limit, upper_limit, formula, source='', visibility=True, start=0, stop=0):
        sensor = {
            'lower_limit': lower_limit,
            'upper_limit': upper_limit,
            'formula': formula,
            'source': source,
            'visible': visibility,
            'start': start,
            'stop': stop
        }

        self.sensors[name] = sensor

        self.Save()

    def Get(self):
        return self.sensors

    def Save(self):
        json_object = ujson.dumps(self.sensors)

        with open(self.filename, 'w+') as settings_file:
            settings_file.write(json_object)

            settings_file.close()

    def Load(self):
        try:
            with open(self.filename, 'r') as sensors_file:
                stored_sensors = ujson.loads(sensors_file.read())

                for k in stored_sensors:
                    self.sensors[k] = stored_sensors[k]

                sensors_file.close()
        except Exception as ex:
            if hasattr(ex, 'message'):
                print(ex.message)
            else:
                print(ex)

            with open(self.filename, 'w+') as sensors_file:
                print('Creating default sensors file...')
                json_object = ujson.dumps(self.sensors)

                sensors_file.write(json_object)

                sensors_file.close()
